FirefoxCustomProfileLauncher (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class FirefoxCustomProfileLauncher

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
          org.openqa.selenium.server.browserlaunchers.FirefoxCustomProfileLauncher

All Implemented Interfaces:
  BrowserLauncher

Direct Known Subclasses:
  ProxyInjectionFirefoxCustomProfileLauncher

    public class FirefoxCustomProfileLauncher

extends AbstractBrowserLauncher

Nested Class Summary
`protected class` | `FirefoxCustomProfileLauncher.FileLockRemainedException`

Field Summary
`protected boolean` | `changeMaxConnections`
`protected LauncherUtils.ProxySetting` | `proxySetting`

Fields inherited from class org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
`browserConfigurationOptions, sessionId`

Constructor Summary
`FirefoxCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, BrowserInstallation browserInstallation)`
`FirefoxCustomProfileLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`

Method Summary
`void` | `close()` Implementation identical to that in FirefoxChromeLauncher.
`java.lang.Process` | `getProcess()` Returns a process if there is an associated one running with this browser launcher (this is not required to be implementd).
`protected void` | `init()`
`protected void` | `killFirefoxProcess()` Wrapper to allow for stubbed-out testing
`protected void` | `launch(java.lang.String url)`
`protected void` | `removeCustomProfileDir()` Wrapper to allow for stubbed-out testing
`static void` | `setChangeMaxConnections(boolean changeMaxConnections)`
`protected void` | `setCustomProfileDir(java.io.File value)`
`protected void` | `setProcess(java.lang.Process p)`

Methods inherited from class org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
`getConfiguration, getPort, launchHTMLSuite, launchRemoteSession`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Field Detail

### proxySetting

    protected LauncherUtils.ProxySetting proxySetting

### changeMaxConnections

    protected boolean changeMaxConnections

Constructor Detail

### FirefoxCustomProfileLauncher

    public FirefoxCustomProfileLauncher(BrowserConfigurationOptions browserOptions,
                                        RemoteControlConfiguration configuration,
                                        java.lang.String sessionId,
                                        java.lang.String browserLaunchLocation)
                                 throws InvalidBrowserExecutableException

Throws:
  `InvalidBrowserExecutableException`

### FirefoxCustomProfileLauncher

    public FirefoxCustomProfileLauncher(BrowserConfigurationOptions browserOptions,
                                        RemoteControlConfiguration configuration,
                                        java.lang.String sessionId,
                                        BrowserInstallation browserInstallation)

Method Detail

### init

    protected void init()

### launch

    protected void launch(java.lang.String url)

  Specified by:
    `launch` in class `AbstractBrowserLauncher`

### close

    public void close()

  Implementation identical to that in FirefoxChromeLauncher.

### removeCustomProfileDir

    protected void removeCustomProfileDir()
                                   throws java.lang.RuntimeException

  Wrapper to allow for stubbed-out testing

  Throws:
    `java.lang.RuntimeException`

### killFirefoxProcess

    protected void killFirefoxProcess()
                               throws FirefoxCustomProfileLauncher.FileLockRemainedException

  Wrapper to allow for stubbed-out testing

  Throws:
    `FirefoxCustomProfileLauncher.FileLockRemainedException`

### setCustomProfileDir

    protected void setCustomProfileDir(java.io.File value)

### setProcess

    protected void setProcess(java.lang.Process p)

### getProcess

    public java.lang.Process getProcess()

  Description copied from interface: `BrowserLauncher`
  Returns a process if there is an associated one running with this browser launcher (this is not required to be implementd).

  Returns:
    a handle to a process if one is available, or null if one is not available or if no browser is running

### setChangeMaxConnections

    public static void setChangeMaxConnections(boolean changeMaxConnections)

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.